@@ -17,10 +17,7 @@ from cdftpy.cdft1d.io_utils import print_simulation
 from cdftpy.cdft1d.potential import compute_lj_potential_mod
 from cdftpy.cdft1d.rdf import analyze_rdf_peaks_sim
 from cdftpy.cdft1d.rdf import write_rdf_sim
-from cdftpy.cdft1d.solvent import comp_dipole_moment, compute_sm_rigid_bond
-from cdftpy.cdft1d.solvent import load_solvent_model
-from cdftpy.utils.units import bohr_2_ang
-from cdftpy.utils.units import hartree_2_kjmol
+from cdftpy.cdft1d.solvent import Solvent, solvent_model_locate
 from cdftpy.utils.units import R
 
 HEADER = """
@@ -39,22 +36,18 @@ DEFAULT_PARAMS = dict(diis_iterations=2, tol=1.0e-9, output_rate=10, max_iter=40
 DG_STRING = "|\u0394\u03B3|"
 
 
-def rsdft_1d(solute, solvent_model, params=None):
+def rsdft_1d(solute, solvent, params=None):
 
     qs = solute["charge"]
     sig_s = solute["sigma"]
     eps_s = solute["eps"]
 
-    solperm = solvent_model.dielectric
-    rho_0 = solvent_model.density
-    sig_v = solvent_model.sigma
-    eps_v = solvent_model.eps
-    qv = solvent_model.charge
-    hbar = solvent_model.hbar
-    xv = solvent_model.x
-    yv = solvent_model.y
-    zv = solvent_model.z
-    zv = solvent_model.z
+    rho_0 = solvent.density
+    sig_v = solvent.sigma
+    eps_v = solvent.eps
+    qv = solvent.charge
+    hbar = solvent.hbar_k
+
 
     if params is None:
         params = DEFAULT_PARAMS
@@ -66,21 +59,18 @@ def rsdft_1d(solute, solvent_model, params=None):
     output_rate = int(params["output_rate"])
 
     if "temp" not in params:
-        params["temp"] = solvent_model.temp
+        params["temp"] = solvent.temp
 
     temp = float(params["temp"])
     beta = 1.0 / (kb * temp)
 
     print(HEADER)
-    print_simulation(solute, solvent_model, params)
+    print_simulation(solute, solvent, params)
 
-    mu2 = comp_dipole_moment(solvent_model) ** 2
-    y3 = (hartree_2_kjmol / bohr_2_ang) * beta * 4 * PI * mu2 * rho_0 / 3
-    y3m = 1.0 - 1.0 / solperm
-    zeta = y3m / y3
+    zeta = solvent.zeta(beta)
 
     # initialize fft
-    ifft = solvent_model.ifft
+    ifft = solvent.ifft
     rgrid = ifft.rgrid
     kgrid = ifft.kgrid
 
@@ -96,7 +86,7 @@ def rsdft_1d(solute, solvent_model, params=None):
     vs_r = vcs_r + vlj_r
 
     # molecular structure factor
-    sm = compute_sm_rigid_bond(xv,yv,zv,kgrid)
+    sm = solvent.sm_k(kgrid)
 
     gl_r, gl_k = compute_gamma_long_range(ifft, hbar, sm, vl_k, vl_r, zeta)
 
@@ -160,7 +150,7 @@ def rsdft_1d(solute, solvent_model, params=None):
 
     return SimpleNamespace(
         solute=SimpleNamespace(**solute),
-        solvent=solvent_model,
+        solvent=solvent,
         ifft=ifft,
         sm=sm,
         f_k=f_k,
@@ -272,14 +262,13 @@ if __name__ == "__main__":
 
     # load solvent model
     solvent_name = "s2"
-    # data_dir = "./data"
-    # solvent_filename = os.path.join(data_dir, f"{solvent_name}.smdl")
-    solvent_model = load_solvent_model(solvent_name)
+    filename = solvent_model_locate(solvent_name)
+    solvent = Solvent.from_file(filename)
 
     solute = dict(name="Cl", charge=-1.0, sigma=4.83, eps=0.05349244)
     params = dict(diis_iterations=2, tol=1.0e-7, max_iter=200)
 
-    sim = rsdft_1d(solute, solvent_model, params=params)
+    sim = rsdft_1d(solute, solvent, params=params)
 
     analyze_rdf_peaks_sim(sim)
 
