@@ -66,7 +66,6 @@ class Solvent(Molecule):
     filename: str
     file_location: str
 
-
     density: float
     temp: float
 
@@ -96,7 +95,7 @@ class Solvent(Molecule):
         solvent["s_k"] = s_k
         solvent["hbar_k"] = hbar
         solvent["kgrid"] = kgrid
-        if kgrid:
+        if kgrid is not None:
             solvent["ifft"] = RadFFT.from_kgrid(kgrid)
         return cls(**solvent,**state)
 
@@ -108,6 +107,33 @@ class Solvent(Molecule):
         zeta = y3m / y3
         return zeta
 
+    def to_file(self,filename):
+        with open(filename,"w") as fp:
+            fp.write("<geometry>\n")
+            fp.write("# site   type   x     y     z\n")
+            for i in range(self.nv):
+                fp.write(F"{self.aname[i]}   {self.atype[i]}    {self.x[i]}     {self.y[i]}     {self.z[i]}\n" )
+
+            fp.write("<interactions>\n")
+            # fp.write("# type   sigma    eps(kj/mol)   charge(e)\n")
+            fp.write(f"#{'type' : <10}{'sigma' : ^10}{'eps' : ^10}{'charge' : >10}\n")
+            for i in range(self.nv):
+                fp.write(F" {self.atype[i]: <10}{self.sigma[i]: ^10}{self.eps[i]: ^10}{self.charge[i]: >10}\n" )
+
+            fp.write("<state>\n")
+            fp.write(F"density {self.density}\n")
+            fp.write(F"temp {self.temp}\n")
+            fp.write(F"dielectric {self.dielectric}\n")
+
+            if self.s_k is not None:
+                fp.write("<s_k>\n")
+                fp.write(F"{self.nv}   {self.ifft.ngrid}\n")
+                for k in range(self.ifft.ngrid):
+                    fp.write(F"{self.kgrid[k]}   ")
+                    for i in range(self.nv):
+                        for j in range(i, self.nv):
+                            fp.write(F"{self.s_k[i,j,k]}  ")
+                    fp.write("\n")
 def solvent_model_locate(solvent_name):
     solvent = solvent_name + ".smdl"
     cwd = pathlib.Path.cwd()
@@ -159,6 +185,5 @@ if __name__ == "__main__":
     params = dict(density=1.0)
     # solvent = Solvent(**params,**geom)
     solvent = Solvent.from_file("../data/s2.smdl")
-    molecule = Molecule.from_file("../data/s2.smdl")
-    print(solvent)
-    print(molecule)
+
+    solvent.to_file("test.dat")
